#!/bin/sh

# Author: Rudy Rucker rudy@monkeybrains.net
# Date: Tue Apr 20 06:47:03 PDT 2004
#
# This script is provided as is and if you are smart, you may very
# well run this on an HTTPs webserver.  Use at your own risk.
#
# This is a simple script to generate views of your mbmon data.
# For fun, I wrote this as a shell script instead of a Perl script.
# If you want a more robust tool, use 'cacti'
#      http://www.raxnet.net/products/cacti/

# set up a cronjob like this:
#  */5 * * * *  /usr/local/bin/mbmon-rrd.pl /var/db/mbmon.rrd
# mbmon-rrd.pl comes with the xmbmon distribution....

# set this to be your rrd database of info updated by mbmon-rrd.pl
RRDDATA='/home/rudy/mbmon/mbmon.rrd'

# this is usually where rrdtool is installed.
RRDTOOL='/usr/local/bin/rrdtool'

# Tweak these next two routines to alter the format of the generated image
generate_voltage_image () {
	${RRDTOOL} graph - \
		-a PNG -w 700 -h 150 \
		--start end-1${TIME} --alt-autoscale \
		--title="${HOST} voltages" \
		--vertical-label Voltage \
		DEF:vc0=${RRDDATA}:vc0:AVERAGE \
		DEF:vc1=${RRDDATA}:vc1:AVERAGE \
		DEF:v33=${RRDDATA}:v33:AVERAGE \
		DEF:v50p=${RRDDATA}:v50p:AVERAGE \
		DEF:v50n=${RRDDATA}:v50n:AVERAGE \
		DEF:v12p=${RRDDATA}:v12p:AVERAGE \
		DEF:v12n=${RRDDATA}:v12n:AVERAGE \
		AREA:v12p#00ff00:12.0V \
		AREA:v50p#cc3300:5.0V \
		LINE1:vc0#0033FF:Core\ 1 \
		LINE2:vc1#0000BB:Core\ 2 \
		LINE3:v33#5020ff:3.3V \
		GPRINT:v12n:MAX:v12-neutral\\:%lg \
		GPRINT:v50n:MAX:v50-neutral\\:%lg
}
generate_temperature_image () {
	${RRDTOOL} graph - \
		-a PNG -w 700 -h 150 \
		--start end-1${TIME} --alt-autoscale \
		--title="${HOST} motherboard and CPU temperature - past ${TIME}" \
		--vertical-label Temperature \
		DEF:cpuC=${RRDDATA}:temp0:AVERAGE \
		DEF:mbC=${RRDDATA}:temp1:AVERAGE \
		CDEF:cpuF=cpuC,1.8,*,32,+ \
		CDEF:mbF=mbC,1.8,*,32,+ \
		AREA:cpuF#00cc00:cpu-C \
		LINE1:mbF#0033FF:mb-C \
		GPRINT:cpuC:MAX:cpu-max\\:%lg \
		GPRINT:mbC:MAX:mb-max\\:%lg
}

# Tweak these routines to alter the HTML generated.
header () {
	echo 'Content-Type: text/html'
	echo 'X-script-author: rudy/MonkeyBrains.NET'
	echo
	echo "<html><head><title>${HTTP_HOST} ${NAME}</title>"
	echo '<meta HTTP-EQUIV="Refresh" CONTENT="300"><body>'
	echo '<link rel="stylesheet" type="text/css" href="httP://www.monkeybrains.net/monkey.css" /></head>'
	echo "<p class=pagetitle>monitoring :: ${HTTP_HOST} ${NAME}</p>"
	echo '<center>'
}
footer () {
	echo "<a href=${SCRIPT_NAME}>Return to menu</a>"
	echo '</center><a href=http://www.nt.phys.kyushu-u.ac.jp/shimizu/download/download.html>mbmon</a></body></html>'
}

# find out the TYPE
case "${QUERY_STRING}" in
t-[ymdha])
	TYPE=t;
	;;
v-[ymdha])
	TYPE=v;
	;;
[tv])
	TYPE=${QUERY_STRING};
	;;
*)
	NAME=":: menu";
	header
	echo " <a href=${SCRIPT_NAME}?t>Temperature</a><br>"
	echo " <a href=${SCRIPT_NAME}?v>Voltage</a><br>"
	footer
	exit
	;;
esac

# map the letter to a name for words on the HTML page
case "${TYPE}" in
t)
	NAME=":: temperature";
	;;
v)
	NAME=":: voltage";
	;;
esac

# find out the TIME
case "${QUERY_STRING}" in
[vt]-y)
	TIME=year;
	;;
[vt]-m)
	TIME=month;
	;;
[vt]-w)
	TIME=week;
	;;
[vt]-d)
	TIME=day;
	;;
[vt]-h)
	TIME=hour;
	;;
[vt]-a)
	TIME=all;
	;;
*)
	TIME=generateDayView;
	;;
esac


case "${TIME}" in
year|month|week|day|hour)
	echo "Content-Type: image/png"
	echo "X-script-author: rudy/MonkeyBrains.NET"
	echo
	case "${TYPE}" in 
	t)
		generate_temperature_image
		;;
	*)
		generate_voltage_image
		;;
	esac
	;;
all)
	header
	echo " <img src=${SCRIPT_NAME}?${TYPE}-d><br />"
	echo " <img src=${SCRIPT_NAME}?${TYPE}-m><br />"
	echo " <img src=${SCRIPT_NAME}?${TYPE}-w><br />"
	echo " <img src=${SCRIPT_NAME}?${TYPE}-y><br />"
	footer
	;;
*)
	header
	echo " <a href=${SCRIPT_NAME}?${TYPE}-a><img src=${SCRIPT_NAME}?${TYPE}-d></a><br />"
	footer
	;;
esac

exit 0
